@@ -30,8 +30,8 @@
 
 #include <curl/curl.h>
 
-#define MINIMAL_PROGRESS_FUNCTIONALITY_INTERVAL 3000000
-#define STOP_DOWNLOAD_AFTER_THIS_MANY_BYTES     6000
+#define MINIMAL_PROGRESS_FUNCTIONALITY_INTERVAL     3000000
+#define STOP_DOWNLOAD_AFTER_THIS_MANY_BYTES         6000
 
 struct myprogress {
   curl_off_t lastruntime; /* type depends on version, see above */
@@ -77,9 +77,9 @@ int main(void)
 {
   CURL *curl;
 
-  CURLcode result = curl_global_init(CURL_GLOBAL_ALL);
-  if(result)
-    return (int)result;
+  CURLcode res = curl_global_init(CURL_GLOBAL_ALL);
+  if(res)
+    return (int)res;
 
   curl = curl_easy_init();
   if(curl) {
@@ -95,14 +95,14 @@ int main(void)
     curl_easy_setopt(curl, CURLOPT_XFERINFODATA, &prog);
 
     curl_easy_setopt(curl, CURLOPT_NOPROGRESS, 0L);
-    result = curl_easy_perform(curl);
+    res = curl_easy_perform(curl);
 
-    if(result != CURLE_OK)
-      fprintf(stderr, "%s\n", curl_easy_strerror(result));
+    if(res != CURLE_OK)
+      fprintf(stderr, "%s\n", curl_easy_strerror(res));
 
     /* always cleanup */
     curl_easy_cleanup(curl);
   }
   curl_global_cleanup();
-  return (int)result;
+  return (int)res;
 }
