@@ -21,6 +21,7 @@
  * SPDX-License-Identifier: curl
  *
  ***************************************************************************/
+
 #include "curl_setup.h"
 
 #if !defined(CURL_DISABLE_COOKIES) || !defined(CURL_DISABLE_ALTSVC) ||  \
@@ -30,6 +31,10 @@
 #include "rand.h"
 #include "curl_fopen.h"
 
+/* The last 2 #include files should be in this order */
+#include "curl_memory.h"
+#include "memdebug.h"
+
 /*
   The dirslash() function breaks a null-terminated pathname string into
   directory and filename components then returns the directory component up
@@ -61,10 +66,10 @@ static char *dirslash(const char *path)
   n = strlen(path);
   if(n) {
     /* find the rightmost path separator, if any */
-    while(n && !IS_SEP(path[n - 1]))
+    while(n && !IS_SEP(path[n-1]))
       --n;
     /* skip over all the path separators, if any */
-    while(n && IS_SEP(path[n - 1]))
+    while(n && IS_SEP(path[n-1]))
       --n;
   }
   if(curlx_dyn_addn(&out, path, n))
@@ -88,14 +93,11 @@ CURLcode Curl_fopen(struct Curl_easy *data, const char *filename,
   CURLcode result = CURLE_WRITE_ERROR;
   unsigned char randbuf[41];
   char *tempstore = NULL;
-#ifndef _WIN32
   struct_stat sb;
-#endif
   int fd = -1;
   char *dir = NULL;
   *tempname = NULL;
 
-#ifndef _WIN32
   *fh = curlx_fopen(filename, FOPEN_WRITETEXT);
   if(!*fh)
     goto fail;
@@ -103,7 +105,6 @@ CURLcode Curl_fopen(struct Curl_easy *data, const char *filename,
     return CURLE_OK;
   }
   curlx_fclose(*fh);
-#endif
   *fh = NULL;
 
   result = Curl_rand_alnum(data, randbuf, sizeof(randbuf));
@@ -115,7 +116,7 @@ CURLcode Curl_fopen(struct Curl_easy *data, const char *filename,
     /* The temp filename should not end up too long for the target file
        system */
     tempstore = curl_maprintf("%s%s.tmp", dir, randbuf);
-    curlx_free(dir);
+    free(dir);
   }
 
   if(!tempstore) {
@@ -124,16 +125,13 @@ CURLcode Curl_fopen(struct Curl_easy *data, const char *filename,
   }
 
   result = CURLE_WRITE_ERROR;
-#ifdef _WIN32
-  fd = curlx_open(tempstore, O_WRONLY | O_CREAT | O_EXCL,
-                  S_IREAD | S_IWRITE);
-#elif (defined(ANDROID) || defined(__ANDROID__)) && \
+#if (defined(ANDROID) || defined(__ANDROID__)) && \
   (defined(__i386__) || defined(__arm__))
   fd = curlx_open(tempstore, O_WRONLY | O_CREAT | O_EXCL,
-                  (mode_t)(S_IRUSR | S_IWUSR | sb.st_mode));
+                  (mode_t)(0600 | sb.st_mode));
 #else
   fd = curlx_open(tempstore, O_WRONLY | O_CREAT | O_EXCL,
-                  S_IRUSR | S_IWUSR | sb.st_mode);
+                  0600 | sb.st_mode);
 #endif
   if(fd == -1)
     goto fail;
@@ -151,8 +149,8 @@ fail:
     unlink(tempstore);
   }
 
-  curlx_free(tempstore);
+  free(tempstore);
   return result;
 }
 
-#endif /* !disabled */
+#endif /* ! disabled */
