@@ -23,7 +23,7 @@
  ***************************************************************************/
 #include "testtrace.h"
 
-#include <toolx/tool_time.h>
+#include "memdebug.h"
 
 struct libtest_trace_cfg debug_config;
 
@@ -95,8 +95,7 @@ int libtest_debug_cb(CURL *curl, curl_infotype type,
   timestr = &timebuf[0];
 
   if(trace_cfg->tracetime) {
-    CURLcode result;
-    struct tm now;
+    struct tm *now;
     struct curltime tv;
     time_t secs;
     tv = curlx_now();
@@ -105,11 +104,10 @@ int libtest_debug_cb(CURL *curl, curl_infotype type,
       known_offset = 1;
     }
     secs = epoch_offset + tv.tv_sec;
-    result = toolx_localtime(secs, &now);
-    if(result)
-      memset(&now, 0, sizeof(now));
+    /* !checksrc! disable BANNEDFUNC 1 */
+    now = localtime(&secs);  /* not thread safe but we do not care */
     curl_msnprintf(timebuf, sizeof(timebuf), "%02d:%02d:%02d.%06ld ",
-                   now.tm_hour, now.tm_min, now.tm_sec, (long)tv.tv_usec);
+                   now->tm_hour, now->tm_min, now->tm_sec, (long)tv.tv_usec);
   }
 
   switch(type) {
