@@ -85,7 +85,7 @@ static CURLcode test_unit2602(const char *arg)
   Curl_dynhds_reset(&hds);
   Curl_dynhds_free(&hds);
 
-  Curl_dynhds_init(&hds, 128, 4 * 1024);
+  Curl_dynhds_init(&hds, 128, 4*1024);
   fail_if(Curl_dynhds_add(&hds, "test1", 5, "123", 3), "add failed");
   fail_if(Curl_dynhds_add(&hds, "test1", 5, "123", 3), "add failed");
   fail_if(Curl_dynhds_cadd(&hds, "blablabla", "thingies"), "add failed");
@@ -100,25 +100,37 @@ static CURLcode test_unit2602(const char *arg)
     fail_unless(Curl_dynhds_ccount_name(&hds, "bLABlaBlA") == 0, "should");
     fail_if(Curl_dynhds_cadd(&hds, "Bla-Bla", "thingies"), "add failed");
 
-    curlx_dyn_init(&dbuf, 32 * 1024);
+    curlx_dyn_init(&dbuf, 32*1024);
     fail_if(Curl_dynhds_h1_dprint(&hds, &dbuf), "h1 print failed");
     if(curlx_dyn_ptr(&dbuf)) {
       fail_if(strcmp(curlx_dyn_ptr(&dbuf),
                      "test1: 123\r\ntest1: 123\r\nBla-Bla: thingies\r\n"),
-              "h1 format differs");
+                     "h1 format differs");
     }
     curlx_dyn_free(&dbuf);
   }
 
   Curl_dynhds_free(&hds);
+  Curl_dynhds_init(&hds, 128, 4*1024);
+  /* continuation without previous header fails */
+  res = Curl_dynhds_h1_cadd_line(&hds, " indented value");
+  fail_unless(res, "add should have failed");
 
-  curlx_dyn_init(&dbuf, 32 * 1024);
+  /* continuation with previous header must succeed */
+  fail_if(Curl_dynhds_h1_cadd_line(&hds, "ti1: val1"), "add");
+  fail_if(Curl_dynhds_h1_cadd_line(&hds, " val2"), "add indent");
+  fail_if(Curl_dynhds_h1_cadd_line(&hds, "ti2: val1"), "add");
+  fail_if(Curl_dynhds_h1_cadd_line(&hds, "\tval2"), "add indent");
+  fail_if(Curl_dynhds_h1_cadd_line(&hds, "ti3: val1"), "add");
+  fail_if(Curl_dynhds_h1_cadd_line(&hds, "     val2"), "add indent");
+
+  curlx_dyn_init(&dbuf, 32*1024);
   fail_if(Curl_dynhds_h1_dprint(&hds, &dbuf), "h1 print failed");
   if(curlx_dyn_ptr(&dbuf)) {
     curl_mfprintf(stderr, "indent concat: %s\n", curlx_dyn_ptr(&dbuf));
     fail_if(strcmp(curlx_dyn_ptr(&dbuf),
                    "ti1: val1 val2\r\nti2: val1 val2\r\nti3: val1 val2\r\n"),
-            "wrong format");
+                   "wrong format");
   }
   curlx_dyn_free(&dbuf);
 
